
/**
 * A read-only tree of objects, with positions.
 * 
 * @author Goodrich & Tamassia
 */

public interface InspectableTree extends InspectablePositionalContainer
{
/** get the root of the tree.
	@return a Position indicating the root.
*/
	public Position root ();

/** get the parent of a specified position.
	@param v   the position whose parent we want.
	@return another Position, the parent (null if there is no parent)
*/
	public Position parent (Position v);

/** get an iterator of the children of a specified position.
	@param v   the position whose children we want.
	@return a PositionIterator (possibly empty) that visits all the children in unspecified order.
*/
	public PositionIterator children (Position v);

/** is the node internal?
	@param v  the position of the node we want to know about
	@return true iff the node has at least one child
*/
	public boolean isInternal (Position v);

/** is the node external (i.e. a leaf)?
	@param v  the position of the node we want to know about
	@return true iff the node is a leaf, i.e. has no children
*/
	public boolean isExternal (Position v);

/** is this the root?
	@param v  the position of the node we're curious about
	@return true iff the node is the root of the tree, i.e. has no parent
*/
	public boolean isRoot (Position v);
}
